@@ -1,15 +1,15 @@
 import abc
+import time
 import json
+import asyncio
 import logging
-from uuid import uuid1
-from typing import Set, Generator, List, Tuple, Optional, Protocol, Union, Type
+from collections import defaultdict
+from typing import Generator, List, Tuple, Optional, Protocol, Union, Type, Dict
 
-from collection_scanner import CollectionScanner
-from scrapinghub.client.exceptions import NotFound
 from scrapinghub.client.jobs import Job
 from scrapy import Item
 
-from shub_workflow.script import BaseScript, BaseLoopScript, JobKey
+from shub_workflow.script import BaseLoopScript, JobKey
 from shub_workflow.deliver.dupefilter import SqliteDictDupesFilter, DupesFilterProtocol
 
 _LOG = logging.getLogger(__name__)
@@ -46,6 +46,9 @@ class BaseDeliverScript(BaseLoopScript, DeliverScriptProtocol):
     # print log every given items processed
     LOG_EVERY = 1000
 
+    # minimal run time in order to ensure target jobs started to be scheduled
+    MIN_RUN_TIME = 30
+
     # define here the fields used to deduplicate items. All them compose the dedupe key.
     # target item values must be strings.
     # for changing behavior, override is_seen_item()
@@ -61,6 +64,8 @@ class BaseDeliverScript(BaseLoopScript, DeliverScriptProtocol):
         self.total_items_count = 0
         self.total_dupe_filtered_items_count = 0
         self.seen_items: DupesFilterProtocol = self.SEEN_ITEMS_CLASS()
+        self.seen_fields: Dict[str, int] = defaultdict(int)
+        self.start_time = time.time()
 
     def add_argparser_options(self):
         super().add_argparser_options()
@@ -103,9 +108,7 @@ class BaseDeliverScript(BaseLoopScript, DeliverScriptProtocol):
                 self._all_jobs_to_tag.append(sj.key)
             if self.total_items_count >= self.MAX_PROCESSED_ITEMS:
                 return False
-        if self.loop_mode:
-            return self.has_delivery_running_spider_jobs(scrapername, target_tags)
-        return False
+        return True
 
     def get_item_unique_key(self, item: Item) -> str:
         assert all(isinstance(item[f], str) for f in self.DEDUPE_KEY_BY_FIELDS)
@@ -128,6 +131,9 @@ class BaseDeliverScript(BaseLoopScript, DeliverScriptProtocol):
             else:
                 self.on_item(item, scrapername)
                 self.add_seen_item(item)
+                for key, value in item.items():
+                    if value:
+                        self.seen_fields[key] += 1
             self.total_items_count += 1
             if self.total_items_count % self.LOG_EVERY == 0:
                 _LOG.info(f"Processed {self.total_items_count} items.")
@@ -136,116 +142,39 @@ class BaseDeliverScript(BaseLoopScript, DeliverScriptProtocol):
         print(json.dumps(item))
 
     def workflow_loop(self) -> bool:
-        retval = False
         for scrapername in self.args.scrapername:
             _LOG.info(f"Processing spider {scrapername}")
-            retval = retval or self.process_spider_jobs(scrapername)
-        return retval
+            if not self.process_spider_jobs(scrapername):
+                return False
+        if self.loop_mode:
+            target_tags = self.get_target_tags()
+            if self.has_delivery_running_spider_jobs(scrapername, target_tags):
+                return True
+            if time.time() - self.start_time < self.MIN_RUN_TIME:
+                return True
+            for scrapername in self.args.scrapername:
+                _LOG.info(f"Processing spider {scrapername}")
+                self.process_spider_jobs(scrapername)
+        return False
 
     def on_close(self):
+        jobs_count = len(self._all_jobs_to_tag)
+        _LOG.info(f"Processed a total of {jobs_count} jobs.")
         _LOG.info(f"Processed a total of {self.total_items_count} items.")
         if self.DEDUPE_KEY_BY_FIELDS:
             _LOG.info(f"A total of {self.total_dupe_filtered_items_count} items were duplicated.")
-        jcount = 0
-        for jkey in self._all_jobs_to_tag:
-            self.add_job_tags(jkey, tags=[self.DELIVERED_TAG])
-            jcount += 1
-            if jcount % 100 == 0:
-                _LOG.info("Marked %d jobs as delivered", jcount)
+        asyncio.run(self._tag_all())
         if hasattr(self.seen_items, "close"):
             self.seen_items.close()
+        for key, value in self.seen_fields.items():
+            self.stats.set_value(f"delivery/fields/count/{key}", value)
+        self.stats.set_value("delivery/items/count", self.total_items_count)
+        self.stats.set_value("delivery/items/duplicated", self.total_dupe_filtered_items_count)
+        self.stats.set_value("delivery/jobs/count", jobs_count)
 
-
-class CachedDeliveredTagsMixin(DeliverScriptProtocol):
-
-    """
-    Usage:
-
-    class MyDeliveryScript(CachedDeliveredTagsMixin, BaseDeliverScript):
-        pass
-
-    Under situations where you need speed and you have lots of jobs to deliver from,
-    this mixin caches in a collection the delivered jobs instead of tagging them
-    one by one.
-
-    An external job scheduled from time to time may take care of tagging jobs while
-    cleaning the collection. This is the recommended approach. Use the class
-    SyncDeliveredScript for creating a script for that purpose.
-    """
-
-    TAGS_COLLECTION = "delivered"
-
-    def __init__(self):
-        super().__init__()
-        self._cache = None
-        self._to_store: Set = set()
-
-    def get_delivered_cached(self):
-        self._cache = set()
-        try:
-            for batch in CollectionScanner(
-                collection_name=self.TAGS_COLLECTION,
-                project_id=super().get_project().key,
-            ).scan_collection_batches():
-                for record in batch:
-                    self._cache.update(record["data"])
-        except NotFound:
-            pass
-        _LOG.info(f"Loaded {len(self._cache)} keys from delivered cache collection.")
-
-    def add_job_tags(self, jobkey: Optional[JobKey] = None, tags: Optional[List[str]] = None):
-        if jobkey is None or tags != [self.DELIVERED_TAG]:
-            super().add_job_tags(jobkey, tags)
-        else:
-            if self._cache is None:
-                self.get_delivered_cached()
-            assert self._cache is not None
-            self._cache.add(jobkey)
-            self._to_store.add(jobkey)
-
-    def sync(self):
-        if self._to_store:
-            col = super().get_project().collections.get_store(self.TAGS_COLLECTION)
-            to_store_all = list(self._to_store)
-            self._to_store = set()
-            to_store_count = len(to_store_all)
-            while to_store_all:
-                to_store, to_store_all = to_store_all[:100], to_store_all[100:]
-                key = str(uuid1())
-                record = {"_key": key, "data": list(to_store)}
-                col.set(record)
-            _LOG.info(f"Synced delivered cache ({to_store_count} jobs).")
-
-    def get_delivery_spider_jobs(self, scrapername: str, target_tags: List[str]) -> Generator[Job, None, None]:
-        if self._cache is None:
-            self.get_delivered_cached()
-        assert self._cache is not None
-        for sj in super().get_delivery_spider_jobs(scrapername, target_tags):
-            if sj.key not in self._cache:
-                yield sj
-
-    def on_close(self):
-        super().on_close()
-        self.sync()
-
-
-class SyncDeliveredScript(BaseScript):
-
-    TAGS_COLLECTION = "delivered"
-    DELIVERED_TAG = "delivered"
-
-    def run(self):
-        store = self.get_project().collections.get_store(self.TAGS_COLLECTION)
-        try:
-            for batch in CollectionScanner(
-                collection_name=self.TAGS_COLLECTION,
-                project_id=super().get_project().key,
-                meta=["_key"],
-            ).scan_collection_batches():
-                for record in batch:
-                    for key in record["data"]:
-                        self.add_job_tags(key, [self.DELIVERED_TAG])
-                    store.delete([record["_key"]])
-                    _LOG.info(f"Synced {len(record['data'])} jobs from {record['_key']}.")
-        except NotFound:
-            pass
+    async def _tag_all(self):
+        while self._all_jobs_to_tag:
+            to_tag, self._all_jobs_to_tag = self._all_jobs_to_tag[:1000], self._all_jobs_to_tag[1000:]
+            cors = [self.async_add_job_tags(jkey, tags=[self.DELIVERED_TAG]) for jkey in to_tag]
+            await asyncio.gather(*cors)
+            _LOG.info("Marked %d jobs as delivered", len(to_tag))
